==> nifi-minifi-cpp-0.12.0-source.tar.gz: nifi-minifi-cpp-0.12.0-source/extensions/sql/data/SQLRowsetProcessor.h <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#include <vector>

#include "SQLRowSubscriber.h"
#include "DatabaseConnectors.h"

namespace org {
namespace apache {
namespace nifi {
namespace minifi {
namespace sql {

class SQLRowsetProcessor {
 public:
  SQLRowsetProcessor(std::unique_ptr<Rowset> rowset, std::vector<std::reference_wrapper<SQLRowSubscriber>> rowSubscribers);

  size_t process(size_t max);

 private:
   void addRow(const Row& row, size_t rowCount);

   template <typename T>
   void processColumn(const std::string& name, const T& value) const {
     for (const auto& subscriber : row_subscribers_) {
       subscriber.get().processColumn(name, value);
     }
   }

 private:
  std::unique_ptr<Rowset> rowset_;
  std::vector<std::reference_wrapper<SQLRowSubscriber>> row_subscribers_;
};

} /* namespace sql */
} /* namespace minifi */
} /* namespace nifi */
} /* namespace apache */
} /* namespace org */

==> nifi-minifi-cpp-0.15.0-source.tar.gz: nifi-minifi-cpp-0.15.0-source/extensions/sql/data/SQLRowsetProcessor.h <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#include <vector>

#include "SQLRowSubscriber.h"
#include "DatabaseConnectors.h"

namespace org {
namespace apache {
namespace nifi {
namespace minifi {
namespace sql {

class SQLRowsetProcessor {
 public:
  SQLRowsetProcessor(std::unique_ptr<Rowset> rowset, std::vector<std::reference_wrapper<SQLRowSubscriber>> row_subscribers);

  size_t process(size_t max);

 private:
   void addRow(const Row& row, size_t rowCount);

   template <typename T>
   void processColumn(const std::string& name, const T& value) const {
     for (const auto& subscriber : row_subscribers_) {
       subscriber.get().processColumn(name, value);
     }
   }

 private:
  std::unique_ptr<Rowset> rowset_;
  std::vector<std::reference_wrapper<SQLRowSubscriber>> row_subscribers_;
};

} /* namespace sql */
} /* namespace minifi */
} /* namespace nifi */
} /* namespace apache */
} /* namespace org */
